@@ -18,14 +18,11 @@
 # along with Total Open Station.  If not, see
 # <http://www.gnu.org/licenses/>.
 
-from . import Parser, Point
+from . import Feature, Parser, Point
 
 
 class FormatParser(Parser):
 
-    def __init__(self, data):
-        Parser.__init__(self, data)
-
     def is_point(self, line):
         if line[2:4] == ('TP'):
             return True
@@ -43,5 +40,6 @@ class FormatParser(Parser):
         if line[0:2] == '08':   # Measurement
             desc = line[63:70].strip()
 
-        p = Point(id, x, y, z, desc)
-        return p
+        point = Point(x, y, z)
+        feature = Feature(point, desc=desc, id=id)
+        return feature
