@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # filename: tops_txt.py
 # Copyright 2008 Luca Bianconi<lc.bianconi@googlemail.com>
-# Copyright 2008,2011 Stefano Costa <steko@iosa.it>
+# Copyright 2019 Stefano Costa <steko@iosa.it>
 #
 # This file is part of Total Open Station.
 #
@@ -20,21 +20,22 @@
 # along with Total Open Station.  If not, see
 # <http://www.gnu.org/licenses/>.
 
+from . import Builder
+
 
 def to_txt(d):
-    string = "%s %s %s\n" % (d[1], d[2], d[3])
+    try:
+        string = "{geom.x} {geom.y} {geom.z}\n".format(geom=d.geometry)
+    except ValueError:
+        string = "{geom.x} {geom.y}\n".format(geom=d.geometry)
     return string
 
-class OutputFormat:
+class OutputFormat(Builder):
 
     """
-    Exports points data in TXT (comma-separated) format line by line.
+    Exports points data in TXT (space-separated) format line by line.
 
-    ``data`` should be an iterable (e.g. list) containing one iterable
-    (e.g.  tuple) for each point. The default order is PID, x, y, z,
-    TEXT.
-
-    This is consistent with our current standard.
+    ``data`` should be an iterable of Feature objects.
     """
 
     def __init__(self, data):
